@@ -4,7 +4,7 @@ use strict;
 use 5.002;
 
 use vars qw($VERSION);
-$VERSION = '1.07a';
+$VERSION = '1.08';
 
 use overload	'""'	=>	\&getTable,
 				fallback => undef;
@@ -547,7 +547,7 @@ sub getTable {
           # Finish up Cell by ending cell start tag, putting content and cell end tag
           $html .=">";
           $html .= $self->{'table:cellstartformat'}{"$i:$j"} if defined $self->{'table:cellstartformat'}{"$i:$j"} ;
-          $html .= ($self->{table}{"$i:$j"} || '');
+          $html .= $self->{table}{"$i:$j"} if defined $self->{table}{"$i:$j"};
 		  $html .= $self->{'table:cellendformat'}{"$i:$j"} if defined $self->{'table:cellendformat'}{"$i:$j"} ;
           
           # if head flag is set print </TH> tag else </TD>
@@ -575,15 +575,19 @@ sub print {
 }
 
 #-------------------------------------------------------
-# Subroutine:  	autoGrow([1|on|true|1|off|false]) 
+# Subroutine:  	autoGrow([1|on|true|0|off|false]) 
 # Author:       John Stumbles
 # Date:		08 Feb 2001
 # Description:  switches on (default) or off auto-grow mode
 #-------------------------------------------------------
 sub autoGrow {
     my $self = shift;
-    $self->{autogrow} = (shift or 1) ;
-    $self->{autogrow} = 0 if $self->{autogrow} =~ /^(?:0|no|off|false|disable)$/i ;
+    $self->{autogrow} = shift;
+	if ( defined $self->{autogrow} && $self->{autogrow} =~ /^(?:no|off|false|disable|0)$/i ) {
+	    $self->{autogrow} = 0;
+	} else {
+		$self->{autogrow} = 1;
+	}
 }
 
 
@@ -664,11 +668,10 @@ sub setCaption {
    my $self = shift;
    $self->{caption} = shift ;
    my $align = uc(shift);
-   if (defined $align && (($align eq "TOP") || ($align eq "BOTTOM")) ) {
+   if (defined $align && (($align eq 'TOP') || ($align eq 'BOTTOM')) ) {
       $self->{caption_align} = $align;
    } else {
-      print STDERR "$0:setCaption:Invalid Alignment\n";
-      return 0;
+      $self->{caption_align} = 'TOP';
    }
 }
 
@@ -1419,6 +1422,12 @@ sub _updateSpanGrid {
 
    my $colspan = $self->{"table:cellcolspan"}{"$row:$col"} || 0;
    my $rowspan = $self->{"table:cellrowspan"}{"$row:$col"} || 0;
+
+	if ($self->{autogrow}) {
+		$self->{cols} = $col + $colspan - 1 unless $self->{cols} > ($col + $colspan - 1 );
+		$self->{rows} = $row + $rowspan - 1 unless $self->{rows} > ($row + $rowspan - 1 );
+	}
+
    my ($i, $j);
    if ($colspan) {
       for ($j=$col+1;(($j <= $self->{cols}) && ($j <= ($col +$colspan -1))); $j++ ) {
